import { type CustomRequestConfig, type AzureOpenAiChatModel } from '@sap-ai-sdk/core';
import { type ModelDeployment } from '@sap-ai-sdk/ai-api/internal.js';
import type { OpenAiChatCompletionParameters } from './openai-types.js';
import { OpenAiChatCompletionResponse } from './openai-response.js';
/**
 * OpenAI client for chat completion.
 */
export declare class OpenAiChatClient {
    private modelDeployment;
    /**
     * Creates an instance of the OpenAI chat client.
     * @param modelDeployment - This configuration is used to retrieve a deployment. Depending on the configuration use either the given deployment ID or the model name to retrieve matching deployments. If model and deployment ID are given, the model is verified against the deployment.
     */
    constructor(modelDeployment: ModelDeployment<AzureOpenAiChatModel>);
    /**
     * Creates a completion for the chat messages.
     * @param data - The input parameters for the chat completion.
     * @param requestConfig - The request configuration.
     * @returns The completion result.
     */
    run(data: OpenAiChatCompletionParameters, requestConfig?: CustomRequestConfig): Promise<OpenAiChatCompletionResponse>;
}
//# sourceMappingURL=openai-chat-client.d.ts.map