import { type CustomRequestConfig, type AzureOpenAiEmbeddingModel } from '@sap-ai-sdk/core';
import { type ModelDeployment } from '@sap-ai-sdk/ai-api/internal.js';
import type { OpenAiEmbeddingParameters, OpenAiEmbeddingOutput } from './openai-types.js';
/**
 * OpenAI client for embeddings.
 */
export declare class OpenAiEmbeddingClient {
    private modelDeployment;
    /**
     * Creates an instance of the OpenAI embedding client.
     * @param modelDeployment - This configuration is used to retrieve a deployment. Depending on the configuration use either the given deployment ID or the model name to retrieve matching deployments. If model and deployment ID are given, the model is verified against the deployment.
     */
    constructor(modelDeployment: ModelDeployment<AzureOpenAiEmbeddingModel>);
    /**
     * Creates an embedding vector representing the given text.
     * @param data - The text to embed.
     * @param requestConfig - The request configuration.
     * @returns The completion result.
     */
    run(data: OpenAiEmbeddingParameters, requestConfig?: CustomRequestConfig): Promise<OpenAiEmbeddingOutput>;
}
//# sourceMappingURL=openai-embedding-client.d.ts.map