import { executeRequest } from '@sap-ai-sdk/core';
import { getDeploymentId } from '@sap-ai-sdk/ai-api/internal.js';
const apiVersion = '2024-02-01';
/**
 * OpenAI client for embeddings.
 */
export class OpenAiEmbeddingClient {
    modelDeployment;
    /**
     * Creates an instance of the OpenAI embedding client.
     * @param modelDeployment - This configuration is used to retrieve a deployment. Depending on the configuration use either the given deployment ID or the model name to retrieve matching deployments. If model and deployment ID are given, the model is verified against the deployment.
     */
    constructor(modelDeployment) {
        this.modelDeployment = modelDeployment;
    }
    /**
     * Creates an embedding vector representing the given text.
     * @param data - The text to embed.
     * @param requestConfig - The request configuration.
     * @returns The completion result.
     */
    async run(data, requestConfig) {
        const deploymentId = await getDeploymentId(this.modelDeployment, 'azure-openai');
        const response = await executeRequest({ url: `/inference/deployments/${deploymentId}/embeddings`, apiVersion }, data, requestConfig);
        return response.data;
    }
}
//# sourceMappingURL=openai-embedding-client.js.map