import { HttpResponse } from '@sap-cloud-sdk/http-client';
import { OpenAiChatCompletionOutput, OpenAiUsage } from './openai-types.js';
/**
 * OpenAI chat completion response.
 */
export declare class OpenAiChatCompletionResponse {
    readonly rawResponse: HttpResponse;
    /**
     * The chat completion response.
     */
    readonly data: OpenAiChatCompletionOutput;
    constructor(rawResponse: HttpResponse);
    /**
     * Usage of tokens in the response.
     * @returns Token usage.
     */
    getTokenUsage(): OpenAiUsage;
    /**
     * Reason for stopping the completion.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The finish reason.
     */
    getFinishReason(choiceIndex?: number): string | undefined;
    /**
     * Parses the Open AI response and returns the content.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The message content.
     */
    getContent(choiceIndex?: number): string | undefined;
    private logInvalidChoiceIndex;
}
//# sourceMappingURL=openai-response.d.ts.map