import { createLogger } from '@sap-cloud-sdk/util';
const logger = createLogger({
    package: 'gen-ai-hub',
    messageContext: 'openai-response'
});
/**
 * OpenAI chat completion response.
 */
export class OpenAiChatCompletionResponse {
    rawResponse;
    /**
     * The chat completion response.
     */
    data;
    constructor(rawResponse) {
        this.rawResponse = rawResponse;
        this.data = rawResponse.data;
    }
    /**
     * Usage of tokens in the response.
     * @returns Token usage.
     */
    getTokenUsage() {
        return this.data.usage;
    }
    /**
     * Reason for stopping the completion.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The finish reason.
     */
    getFinishReason(choiceIndex = 0) {
        this.logInvalidChoiceIndex(choiceIndex);
        return this.data.choices[choiceIndex]?.finish_reason;
    }
    /**
     * Parses the Open AI response and returns the content.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The message content.
     */
    getContent(choiceIndex = 0) {
        this.logInvalidChoiceIndex(choiceIndex);
        return this.data.choices[choiceIndex]?.message?.content;
    }
    logInvalidChoiceIndex(choiceIndex) {
        if (choiceIndex < 0 || choiceIndex >= this.data.choices.length) {
            logger.error(`Choice index ${choiceIndex} is out of bounds.`);
        }
    }
}
//# sourceMappingURL=openai-response.js.map